@@ -53,6 +53,10 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test12.cpp",
                                     "test13.h",
                                     "test13.cpp",
+                                    "test14.h",
+                                    "test14.cpp",
+                                    "test15.h",
+                                    "test15.cpp",
                                     "test_dpointer.cpp",
                                     "test_dpointer.h",
                                     "test_qdebugcategory.cpp",
@@ -77,20 +81,22 @@ static CompilerTestSet testCases = {"test1.cpp",
                                     "test_subgroups.h",
                                     nullptr};
 
-static CompilerTestSet testCasesToRun = {"test1",
-                                         "test2",
-                                         "test3",
-                                         "test3a",
-                                         "test4",
-                                         "test5",
-                                         "test6",
-                                         "test7",
-                                         "test8",
-                                         "test9",
-                                         "test10",
-                                         "test11",
-                                         "test12",
-                                         "test13",
+static CompilerTestSet testCasesToRun = {"Test1",
+                                         "Test2",
+                                         "Test3",
+                                         "Test3a",
+                                         "Test4",
+                                         "Test5",
+                                         "Test6",
+                                         "Test7",
+                                         "Test8",
+                                         "Test9",
+                                         "Test10",
+                                         "Test11",
+                                         "Test12",
+                                         "Test13",
+                                         "Test14",
+                                         "Test15",
                                          "test_enums_and_properties",
                                          "test_dpointer",
                                          "test_qdebugcategory",
@@ -102,6 +108,26 @@ static CompilerTestSet testCasesToRun = {"test1",
                                          "test_properties_minmax",
                                          "test_param_minmax",
                                          "test_subgroups",
+                                         "Test1_cmake",
+                                         "Test2_cmake",
+                                         "Test3_cmake",
+                                         "Test3a_cmake",
+                                         "Test4_cmake",
+                                         "Test5_cmake",
+                                         "Test6_cmake",
+                                         "Test7_cmake",
+                                         "Test8_cmake",
+                                         "Test9_cmake",
+                                         "Test10_cmake",
+                                         "Test11_cmake",
+                                         "Test12_cmake",
+                                         "Test13_cmake",
+                                         "Test14_cmake",
+                                         "Test15_cmake",
+                                         "test_dpointer_cmake",
+                                         "test_signal_cmake",
+                                         "test_emptyentries_cmake",
+                                         "test_subgroups_cmake",
                                          nullptr};
 
 #if 0
@@ -133,7 +159,7 @@ void KConfigCompiler_Test::testBaselineComparison()
 {
     QFETCH(QString, testName);
 
-    QFile file(QFINDTESTDATA(testName));
+    QFile file(testName);
     QFile fileRef(QFINDTESTDATA(testName + QLatin1String(".ref")));
 
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
