@@ -54,16 +54,6 @@ public:
      * @param group name of group
      */
     KConfigGroup(KConfigBase *master, const QString &group);
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
-    /**
-     * Overload for KConfigGroup(KConfigBase*,const QString&)
-     *
-     * @param group name of group, encoded in UTF-8
-     * @deprecated Since 5.240, use QString overload
-     */
-    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
-    KConfigGroup(KConfigBase *master, const char *group);
-#endif
 
     /**
      * Construct a read-only config group.
@@ -74,29 +64,9 @@ public:
      * as @p master.
      */
     KConfigGroup(const KConfigBase *master, const QString &group);
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
-    /**
-     * Overload for KConfigGroup(const KConfigBase*,const QString&)
-     *
-     * @param group name of group, encoded in UTF-8
-     * @deprecated Since 5.240, use QString overload
-     */
-    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
-    KConfigGroup(const KConfigBase *master, const char *group);
-#endif
 
     /** Overload for KConfigGroup(const KConfigBase*,const QString&) */
     KConfigGroup(const QExplicitlySharedDataPointer<KSharedConfig> &master, const QString &group);
-#if KCONFIGCORE_ENABLE_DEPRECATED_SINCE(5, 241)
-    /**
-     * Overload for KConfigGroup(const KConfigBase*,const QString&)
-     *
-     * @param group name of group, encoded in UTF-8
-     * @deprecated Since 5.240, use QString overload
-     */
-    KCONFIGCORE_DEPRECATED_VERSION_BELATED(5, 241, 5, 240, "Use QString overload")
-    KConfigGroup(const QExplicitlySharedDataPointer<KSharedConfig> &master, const char *group);
-#endif
 
     /**
      * Creates a copy of a group.
@@ -190,6 +160,13 @@ public:
      */
     void moveValuesTo(const QList<const char *> &keys, KConfigGroup &other, WriteConfigFlags pFlags = Normal);
 
+    /**
+     * Moves the key-value pairs from one config group to the other.
+     *
+     * @since 6.3
+     */
+    void moveValuesTo(KConfigGroup &other, WriteConfigFlags pFlags = Normal);
+
     /**
      * Returns the group that this group belongs to
      *
@@ -709,6 +686,9 @@ private:
      * @return @p value converted to QVariant, or @p aDefault if @p value is invalid or cannot be converted.
      */
     static QVariant convertToQVariant(const char *pKey, const QByteArray &value, const QVariant &aDefault);
+
+    KCONFIGCORE_NO_EXPORT void moveValue(const char *key, KConfigGroup &other, WriteConfigFlags pFlags);
+
     // exported for usage by KServices' KService & KServiceAction
     friend class KServicePrivate; // XXX yeah, ugly^5
     friend class KServiceAction;
